# Changelog

We [keep a Changelog](https://keepachangelog.com/en/1.0.0/) using [semantic versioning](https://semver.org/spec/v2.0.0.html).


## [Version 2.1.1] - Released 2023-01-29

### Changed
* Update requirements
* Support 311

## Fixed
* Fix numpy float issue


## [Version 2.0.0] - 2019-06-25

### Changed
* Start a changelog
* Publish wheels


## [Version 1.2.0] - 2019-06-24

### Added 
* Changes are undocumented before this point. 
